Function rmp::encode::write_nil
[−]
[src]
pub fn write_nil<W>(wr: &mut W) -> Result<(), FixedValueWriteError> where W: WriteEncodes and attempts to write a nil value into the given write.
According to the MessagePack specification, a nil value is represented as a single 0xc0 byte.
Errors
This function will return FixedValueWriteError on any I/O error occurred while writing the nil
marker.